@@ -179,8 +179,7 @@ static void InsertNthWeightedPoint(PyArrayObject* points,
   double y = *GETPTR2D<double>(points, n, 1);
   double z = *GETPTR2D<double>(points, n, 2);
   double w = weighted ? *GETPTR2D<double>(points, n, 3) : 0.0;
-  int group_name = rel_homology
-                   ? static_cast<int>(*GETPTR2D<double>(points, n, 3 + weighted)) : -1;
+  int group_name = GroupName(3, points, n, weighted, rel_homology);
   points_vector->emplace_back(Weighted_point(Bare_point(x, y, z), w),
                               VertexInfo{static_cast<int>(n), group_name});
 }
