@@ -55,7 +55,6 @@ public:
   typename AsVb::Vertex_handle base;
   int vertex_index;
   int group_name;
-  int vertex_offset[3];
 };
 // Cell type
 typedef CGAL::Periodic_3_triangulation_ds_cell_base_3<> DsCb;
@@ -207,9 +206,9 @@ static int PeriodicAlphaShape3_init(PeriodicAlphaShape3* self, PyObject* args, P
 
   npy_intp* dims = PyArray_DIMS(points);
 
-#ifdef PERIODIC_ALPHA_SHAPE_WITH_WEIGHT
-  std::list<Weighted_point> points_array;
-
+  std::vector<Weighted_point> points_array;
+  npy_intp num_points = dims[0];
+  
   for (npy_intp i=0; i<dims[0]; ++i){
     double x = *GETPTR2D<double>(points, i, 0);
     double y = *GETPTR2D<double>(points, i, 1);
@@ -217,91 +216,55 @@ static int PeriodicAlphaShape3_init(PeriodicAlphaShape3* self, PyObject* args, P
     double w = (weighted==1) ? *GETPTR2D<double>(points, i, 3) : 0.0;
     points_array.push_back(Weighted_point(Bare_point(x,y,z),w));
   }
-#else
-  std::vector<P3T3::Point> points_array;
 
-  for (npy_intp i=0; i<dims[0]; ++i){
-    double x = *GETPTR2D<double>(points, i, 0);
-    double y = *GETPTR2D<double>(points, i, 1);
-    double z = *GETPTR2D<double>(points, i, 2);
-    P3T3::Point pt(x,y,z);
-    points_array.push_back(pt);
-  }
-#endif
-
-  Iso_cuboid domain(xmin,ymin,zmin,xmax,ymax,zmax);  // the fundamental domain
+  Iso_cuboid domain(xmin, ymin, zmin, xmax, ymax, zmax);  // the fundamental domain
 
   P3T3 triangulation(points_array.begin(), points_array.end(), domain);
 
-  Covering_sheets cs = triangulation.number_of_sheets();
-
-//  triangulation.convert_to_27_sheeted_covering();
+  // triangulation.convert_to_27_sheeted_covering();
   triangulation.convert_to_1_sheeted_covering();
-  cs = triangulation.number_of_sheets();
+
 
   self->alpha_shape_ = new CGAL_AlphaShape3(triangulation, 0, CGAL_AlphaShape3::GENERAL);
 
+  // Create a map from coordinates of vertices to indices
+  std::map<CGAL_AlphaShape3::Weighted_point, int> coord2index;
+  for (int i = 0; i < num_points; ++i)
+    coord2index.insert(std::make_pair(points_array[i], i));
+
   // 代表系の vertex_handle を base で覚えておく
-  std::map<CGAL_AlphaShape3::Weighted_point,CGAL_AlphaShape3::Vertex_handle> originals;
-  int index=0;
-  for(
-    auto it = self->alpha_shape_->vertices_begin();
-    it != self->alpha_shape_->vertices_end();
-    ++it, ++index
-  )
-  {
+  std::map<CGAL_AlphaShape3::Weighted_point,CGAL_AlphaShape3::Vertex_handle> coord2original;
+  for (auto it = self->alpha_shape_->unique_vertices_begin();
+       it != self->alpha_shape_->unique_vertices_end();
+       ++it) {
     CGAL_AlphaShape3::Periodic_point pp = self->alpha_shape_->periodic_point(it);
-    if( pp.second.x()==0 && pp.second.y()==0 && pp.second.z()==0 ){
-      originals.insert( std::make_pair(pp.first,it) );
-    }
+    coord2original.insert(std::make_pair(pp.first, it));
+    it->vertex_index = coord2index.at(pp.first);
+    it->group_name = GroupName(3, points, it->vertex_index, weighted, rel_homology);
   }
 
   // base を割り当てる
-  for(
-    auto it = self->alpha_shape_->vertices_begin();
-    it != self->alpha_shape_->vertices_end();
-    ++it, ++index
-  )
-  {
+  for (auto it = self->alpha_shape_->vertices_begin(); it != self->alpha_shape_->vertices_end(); ++it) {
     CGAL_AlphaShape3::Periodic_point pp = self->alpha_shape_->periodic_point(it);
-    auto piter = originals.find(pp.first);
-    if( piter != originals.end() ){
+    auto piter = coord2original.find(pp.first);
+    if (piter != coord2original.end()) {
       it->base = piter->second;
-    }else{
+    } else {
       PyErr_SetString(PyExc_ValueError, "No original point.");
       return -1;
     }
-    it->vertex_index = -1;
-    it->vertex_offset[0] = pp.second.x();
-    it->vertex_offset[1] = pp.second.y();
-    it->vertex_offset[2] = pp.second.z();
-    it->group_name = rel_homology
-                     ? static_cast<int>(*GETPTR2D<double>(points, index, 3+weighted)) : -1;
-  }
-
-  // vertex_index を割り当てる
-  index=0;
-  for(
-    auto it = self->alpha_shape_->unique_vertices_begin();
-    it != self->alpha_shape_->unique_vertices_end();
-    ++it, ++index
-  )
-  {
-    it->vertex_index = index;
   }
 
   // 代表系の cell を unique_cells で記憶しておく
-  for (
-    auto iter = self->alpha_shape_->cells_begin();
-    iter != self->alpha_shape_->cells_end();
-    ++iter)
-  {
-      if( isOverlappingCell(iter) ){
-        PyErr_SetString(PyExc_ValueError, "Overlapping cells.");
-        return -1;
-      }else{
-        self->unique_cells.push_back(iter);
-      }
+  for (auto iter = self->alpha_shape_->cells_begin();
+       iter != self->alpha_shape_->cells_end();
+       ++iter) {
+    if (isOverlappingCell(iter)) {
+      PyErr_SetString(PyExc_ValueError, "Overlapping cells.");
+      return -1;
+    } else {
+      self->unique_cells.push_back(iter);
+    }
   }
 
   return 0;
