@@ -1,21 +1,17 @@
 import struct
 
 import numpy as np
-import msgpack
-from forwardable import forwardable
 from cached_property import cached_property
 
-from homcloud.index_map import IndexMapForBitmap, IndexMapForCubical
 from homcloud.pict.utils import nd_indices
-from homcloud.base_filtration import FiltrationWithIndex
-import homcloud.homccube as homccube
+from homcloud.base_filtration import Filtration
 from homcloud.cubical_ext import CubicalFiltrationExt
 from homcloud.pdgm_format import PDGMWriter, SimpleChunk, BitmapInformationChunk, BinaryChunk
+from homcloud.delegate import forwardable
 
 
 class Bitmap(object):
-    def __init__(self, array, flip_levels_sign=False, periodicity=None,
-                 save_boundary_map=False):
+    def __init__(self, array, flip_levels_sign=False, periodicity=None, save_boundary_map=False):
         self.array = array
         self.flip_levels_sign = flip_levels_sign
         self.periodicity = periodicity or [False] * array.ndim
@@ -26,14 +22,12 @@ class Bitmap(object):
         keys = np.argsort(self.array, axis=None, kind="mergesort")
         index_to_level = self.sign * self.array.flatten()[keys]
         index_bitmap = invert_permutation(keys).reshape(self.array.shape)
-        return BitmapFiltration(index_bitmap, self.periodicity,
-                                index_to_level, indices[keys, :],
-                                self.flip_levels_sign)
+        return BitmapFiltration(
+            index_bitmap, self.periodicity, index_to_level, indices[keys, :], self.flip_levels_sign
+        )
 
     def build_cubical_filtration(self):
-        cubefilt_ext = CubicalFiltrationExt(self.array.astype(float),
-                                            self.periodicity,
-                                            self.save_boundary_map)
+        cubefilt_ext = CubicalFiltrationExt(self.array.astype(float), self.periodicity, self.save_boundary_map)
         return CubicalFiltration(cubefilt_ext, self.flip_levels_sign)
 
     def build_filtration(self, cubical):
@@ -47,9 +41,8 @@ class Bitmap(object):
         return -1 if self.flip_levels_sign else 1
 
 
-class BitmapFiltration(FiltrationWithIndex):
-    def __init__(self, index_bitmap, periodicity, index_to_level, index_to_pixel,
-                 sign_flipped):
+class BitmapFiltration(Filtration):
+    def __init__(self, index_bitmap, periodicity, index_to_level, index_to_pixel, sign_flipped):
         self.index_bitmap = index_bitmap
         self.periodicity = periodicity
         self.index_to_level = index_to_level
@@ -57,16 +50,10 @@ class BitmapFiltration(FiltrationWithIndex):
         self.sign_flipped = sign_flipped
         self.dim = index_bitmap.ndim
 
-    @property
-    def index_map(self):
-        return IndexMapForBitmap(self.index_to_pixel, self.index_to_level, self.dim,
-                                 self.sign_flipped, self.index_bitmap.shape)
-
     def write_dipha_complex(self, f):
-        """Write a picture to f with the dipha format.
-        """
+        """Write a picture to f with the dipha format."""
         if any(self.periodicity):
-            raise(NotImplementedError("dipha does not support periodic bitmap"))
+            raise NotImplementedError("dipha does not support periodic bitmap")
 
         f.write(struct.pack("qq", 8067171840, 1))
         f.write(struct.pack("qq", self.index_bitmap.size, self.dim))
@@ -76,18 +63,6 @@ class BitmapFiltration(FiltrationWithIndex):
         for pixel in self.index_bitmap.flatten():
             f.write(struct.pack("d", pixel))
 
-    def compute_diagram_by_homccube(self, outpath, algorithm):
-        dipha_binary = homccube.compute_pd(
-            self.index_bitmap.astype(np.int32), self.periodicity,
-            self.parse_homccube_algorithm(algorithm), True
-        )
-
-        with open(outpath, "wb") as f:
-            f.write(msgpack.packb({
-                "diagram": dipha_binary,
-                "index-map": self.index_map.to_dict(),
-            }, use_bin_type=True))
-
     def compute_pdgm(self, f, algorithm=None, save_suppl_info=True):
         writer = PDGMWriter(f, "bitmap", self.dim)
         writer.sign_flipped = self.sign_flipped
@@ -95,12 +70,9 @@ class BitmapFiltration(FiltrationWithIndex):
         writer.save_pairs(pairs, self.index_to_level, save_suppl_info)
 
         if save_suppl_info:
-            writer.append_chunk(SimpleChunk("index_to_level",
-                                            list(self.index_to_level)))
-            writer.append_chunk(SimpleChunk("index_to_pixel",
-                                            self.index_to_pixel.tolist()))
-            writer.append_chunk(BitmapInformationChunk(self.index_bitmap.shape,
-                                                       self.periodicity))
+            writer.append_chunk(SimpleChunk("index_to_level", list(self.index_to_level)))
+            writer.append_chunk(SimpleChunk("index_to_pixel", self.index_to_pixel.tolist()))
+            writer.append_chunk(BitmapInformationChunk(self.index_bitmap.shape, self.periodicity))
         writer.write()
 
     def favorite_algorithm(self):
@@ -121,12 +93,9 @@ def invert_permutation(a):
     return s
 
 
-@forwardable()
-class CubicalFiltration(FiltrationWithIndex):
-    def_delegators("cubefilt_ext", "value_at")
-    def_delegators("cubefilt_ext", "encode_cube")
-    def_delegators("cubefilt_ext", "decode_cube")
-    def_delegators("cubefilt_ext", "all_cubes")
+@forwardable
+class CubicalFiltration(Filtration):
+    __delegator_definitions__ = {"cubefilt_ext": ["value_at", "encode_cube", "decode_cube", "all_cubes"]}
 
     def __init__(self, cubefilt_ext, sign_flipped):
         self.cubefilt_ext = cubefilt_ext
@@ -163,13 +132,6 @@ class CubicalFiltration(FiltrationWithIndex):
     def write_dipha_complex(self, output):
         output.write(self.cubefilt_ext.dipha_byte_sequence())
 
-    @property
-    def index_map(self):
-        return IndexMapForCubical(
-            self.index_to_level, self.sign_flipped,
-            self.cubefilt_ext.array.shape, self.cubefilt_ext.sorted_cubes
-        )
-
     @staticmethod
     def favorite_algorithm():
         return "phat-twist"
@@ -180,12 +142,9 @@ class CubicalFiltration(FiltrationWithIndex):
         writer.save_pairs(pairs, self.index_to_level, save_suppl_info)
 
         if save_suppl_info:
-            writer.append_simple_chunk("index_to_level",
-                                       self.index_to_level.tolist())
+            writer.append_simple_chunk("index_to_level", self.index_to_level.tolist())
             writer.append_simple_chunk("index_to_cube", self.index_to_cube)
-            writer.append_chunk(BitmapInformationChunk(self.shape,
-                                                       self.periodicity))
+            writer.append_chunk(BitmapInformationChunk(self.shape, self.periodicity))
         if boundary_map_byte_sequence:
-            writer.append_chunk(BinaryChunk("boundary_map",
-                                            boundary_map_byte_sequence))
+            writer.append_chunk(BinaryChunk("boundary_map", boundary_map_byte_sequence))
         writer.write()
