@@ -5,9 +5,7 @@ import sys
 import numpy as np
 import msgpack
 
-from homcloud.pdgm_format import (
-    PDGMWriter, SimpleChunk, AlphaInformationChunk
-)
+from homcloud.pdgm_format import PDGMWriter, SimpleChunk
 from homcloud.version import __version__
 from homcloud.license import add_argument_for_license
 from homcloud.utils import load_symbols
@@ -15,7 +13,7 @@ from homcloud.utils import load_symbols
 
 def coboundary_map(input_dim, boundary_map):
     cobmap = defaultdict(list)
-    for (index, (d, boundary)) in enumerate(boundary_map):
+    for index, (d, boundary) in enumerate(boundary_map):
         if d == input_dim:
             for b in boundary:
                 cobmap[b].append(index)
@@ -57,10 +55,9 @@ class PHTrees(object):
                 root2.parent = root1.death_index
                 root2.shortcut = root1
 
-        for (facet, coboundary) in sorted(self.coboundary_map.items(), reverse=True):
+        for facet, coboundary in sorted(self.coboundary_map.items(), reverse=True):
             if len(coboundary) == 2:
-                merge(self.root(self.node(coboundary[0])),
-                      self.root(self.node(coboundary[1])))
+                merge(self.root(self.node(coboundary[0])), self.root(self.node(coboundary[1])))
             else:
                 merge(self.root(self.node(coboundary[0])), self.infinity)
 
@@ -97,17 +94,17 @@ class Node(object):
 
 
 def argument_parser():
-    p = argparse.ArgumentParser(
-        description="Comput a PH trees from a point cloud"
-    )
+    p = argparse.ArgumentParser(description="Comput a PH trees from a point cloud")
     p.add_argument("-V", "--version", action="version", version=__version__)
-    p.add_argument("-d", "--dimension", type=int, required=True,
-                   help="dimension of the input data")
+    p.add_argument("-d", "--dimension", type=int, required=True, help="dimension of the input data")
     p.add_argument("--vertex-symbols", help="vertex symbols file")
-    p.add_argument("-w", "--weighted", action="store_true", default=False,
-                   help="use an weighted alpha filtration")
-    p.add_argument("--no-square", action="store_true", default=False,
-                   help="no squared output, if a birth radius is negative, the output is -sqrt(abs(r))")
+    p.add_argument("-w", "--weighted", action="store_true", default=False, help="use an weighted alpha filtration")
+    p.add_argument(
+        "--no-square",
+        action="store_true",
+        default=False,
+        help="no squared output, if a birth radius is negative, the output is -sqrt(abs(r))",
+    )
     p.add_argument("--square", action="store_const", const=False, dest="no_square")
     p.add_argument("--input-type", help="input type (pdgm/pointcloud)")
     add_argument_for_license(p)
@@ -123,11 +120,11 @@ def main(args=None):
     pointcloud = np.loadtxt(args.input)
 
     alpha_shape = AlphaShape.build(
-        pointcloud, args.dimension, args.weighted,
+        pointcloud,
+        args.dimension,
+        args.weighted,
     )
-    filt = alpha_shape.create_filtration(args.no_square,
-                                         load_symbols(args.vertex_symbols),
-                                         True)
+    filt = alpha_shape.create_filtration(args.no_square, load_symbols(args.vertex_symbols), True)
     matrix = filt.build_phat_matrix()
     boundary_map = msgpack.loads(matrix.boundary_map_byte_sequence(), raw=False)
 
