@@ -1,9 +1,10 @@
 import numpy as np
 from scipy.ndimage import gaussian_filter
-from forwardable import forwardable
+
+from homcloud.delegate import forwardable
 
 
-@forwardable()
+@forwardable
 class Histogram(object):
     """A histogram, normally used for representing persistence diagrams.
     The PDHistogram subclass is used for this purpose.
@@ -17,20 +18,19 @@ class Histogram(object):
         self.values_as_float = values.astype(float)
         self.ess_values = ess_values
 
-    def_delegators("histospec", "xedges, yedges, sign_flipped")
-    def_delegators("histospec", "xy_extent, x_range, y_range, x_bins, y_bins")
+    __delegator_definitions__ = {
+        "histospec": ["xedges", "yedges", "sign_flipped", "xy_extent", "x_range", "y_range", "x_bins", "y_bins"]
+    }
 
     def maxvalue(self):
         return max([np.max(self.values), np.max(np.array(self.ess_values, dtype=float), initial=-np.inf)])
 
     def vectorize(self):
-        """Return vectorized histogram as a 1D ndarray of floats.
-        """
+        """Return vectorized histogram as a 1D ndarray of floats."""
         return self.values[self.histospec.vectorize_mask()]
 
     def value_at(self, birth, death):
-        """Internally used by vectorize().
-        """
+        """Internally used by vectorize()."""
         y_index = np.searchsorted(self.yedges, death)
         x_index = np.searchsorted(self.xedges, birth)
         if not ((0 < y_index < self.yedges.size) and (0 < x_index < self.xedges.size)):
@@ -51,7 +51,7 @@ class Histogram(object):
         y_indices = histinfo["y-indices"]
         x_indices = histinfo["x-indices"]
         values = np.zeros((len(y_edges) - 1, len(x_edges) - 1), dtype=vector.dtype)
-        for (y, x, val) in zip(y_indices, x_indices, vector):
+        for y, x, val in zip(y_indices, x_indices, vector):
             values[y, x] = val
 
         return cls(values, HistoSpec(x_edges, y_edges))
@@ -71,7 +71,7 @@ class Histogram(object):
             values = self.values.flatten()
 
         min_rank, max_rank = rank_range
-        ranks = np.argsort(values.flatten())[::-1][min_rank:max_rank - min_rank + 1]
+        ranks = np.argsort(values.flatten())[::-1][min_rank : max_rank - min_rank + 1]
         mask = np.full_like(values, False, dtype=bool)
         mask[ranks] = True
 
@@ -89,9 +89,7 @@ class Histogram(object):
         Args:
         sigma -- standard deviation of the gaussian distribution
         """
-        self.values = gaussian_filter(
-            self.values, self.histospec.normalized_standard_deviation(sigma)
-        )
+        self.values = gaussian_filter(self.values, self.histospec.normalized_standard_deviation(sigma))
 
     def apply_weight(self, weight_func):
         """Apply (multiply) weights to all values in bins.
@@ -114,8 +112,8 @@ class Histogram(object):
 
 
 class Ruler(object):
-    """A pair of min-max (range) and # of bins.
-    """
+    """A pair of min-max (range) and # of bins."""
+
     def __init__(self, minmax, bins):
         self.minmax = minmax
         self.bins = bins
@@ -141,8 +139,7 @@ class Ruler(object):
 
 
 class HistoSpec(object):
-    def __init__(self, xedges, yedges, sign_flipped=False,
-                 x_ruler=None, y_ruler=None):
+    def __init__(self, xedges, yedges, sign_flipped=False, x_ruler=None, y_ruler=None):
         self.xedges = xedges
         self.yedges = yedges
         self.sign_flipped = sign_flipped
@@ -151,52 +148,42 @@ class HistoSpec(object):
 
     @staticmethod
     def from_rulers(x_ruler, y_ruler, sign_flipped=False):
-        return HistoSpec(
-            x_ruler.edges(), y_ruler.edges(), sign_flipped, x_ruler, y_ruler
-        )
+        return HistoSpec(x_ruler.edges(), y_ruler.edges(), sign_flipped, x_ruler, y_ruler)
 
     def xy_extent(self):
-        """Return [xmin, xmax, ymin, ymax].
-        """
+        """Return [xmin, xmax, ymin, ymax]."""
         return [self.xedges[0], self.xedges[-1], self.yedges[0], self.yedges[-1]]
 
     def x_range(self):
-        """Return the range of the histogram along with x-axis as a pair of (min, max).
-        """
+        """Return the range of the histogram along with x-axis as a pair of (min, max)."""
         return (self.xedges[0], self.xedges[-1])
 
     def y_range(self):
-        """Return the range of the histogram along with y-axis as a pair of (min, max).
-        """
+        """Return the range of the histogram along with y-axis as a pair of (min, max)."""
         return (self.yedges[0], self.yedges[-1])
 
     def x_bins(self):
-        """Return the number of bins of x-axis.
-        """
+        """Return the number of bins of x-axis."""
         return self.xedges.size - 1
 
     def y_bins(self):
-        """Return the number of bins of y-axis.
-        """
+        """Return the number of bins of y-axis."""
         return self.yedges.size - 1
 
     def vectorize_mask(self):
-        """Internally used by vectorize().
-        """
+        """Internally used by vectorize()."""
         if self.sign_flipped:
             return self.xedges_of_bins() > self.yedges_of_bins()
         else:
             return self.xedges_of_bins() < self.yedges_of_bins()
 
     def xedges_of_bins(self):
-        """Internally used by vectorize().
-        """
+        """Internally used by vectorize()."""
         xedges = self.xedges[1:] if self.sign_flipped else self.xedges[:-1]
         return np.repeat(xedges.reshape((1, self.x_bins())), self.y_bins(), axis=0)
 
     def yedges_of_bins(self):
-        """Internally used by vectorize().
-        """
+        """Internally used by vectorize()."""
         yedges = self.yedges[:-1] if self.sign_flipped else self.yedges[1:]
         return np.repeat(yedges.reshape((self.y_bins(), 1)), self.x_bins(), axis=1)
 
@@ -208,8 +195,7 @@ class HistoSpec(object):
         return sigma / self.x_ruler.bin_width()
 
     def coordinates_of_center_of_bins(self):
-        """Internally used by vectorize().
-        """
+        """Internally used by vectorize()."""
         x_centers = (self.xedges[:-1] + self.xedges[1:]) / 2
         y_centers = (self.yedges[:-1] + self.yedges[1:]) / 2
         xs = np.repeat(x_centers.reshape((1, self.x_bins())), self.y_bins(), axis=0)
@@ -222,8 +208,7 @@ class HistoSpec(object):
         return np.vstack((xs[mask], ys[mask])).transpose()
 
     def indices_for_vectorization(self):
-        """Internally used by vectorize().
-        """
+        """Internally used by vectorize()."""
         yindices, xindices = np.indices((self.y_bins(), self.x_bins()))
         mask = self.vectorize_mask()
         return (yindices[mask], xindices[mask])
@@ -233,19 +218,19 @@ class HistoSpec(object):
 
     def histogram_from_diagram(self, diagram, cls=Histogram):
         values, *_ = np.histogram2d(
-            diagram.deaths, diagram.births, bins=(self.y_bins(), self.x_bins()),
-            range=((self.y_range(), self.x_range()))
-        )
-        ess_values, _ = np.histogram(
-            diagram.essential_births, bins=self.x_bins(), range=self.x_range()
+            diagram.deaths,
+            diagram.births,
+            bins=(self.y_bins(), self.x_bins()),
+            range=((self.y_range(), self.x_range())),
         )
+        ess_values, _ = np.histogram(diagram.essential_births, bins=self.x_bins(), range=self.x_range())
 
         return cls(values, self, ess_values)
 
     def histogram_from_vector(self, vector, cls=Histogram):
         y_indices, x_indices = self.indices_for_vectorization()
         values = np.zeros((self.y_bins(), self.x_bins()), dtype=vector.dtype)
-        for (y, x, val) in zip(y_indices, x_indices, vector):
+        for y, x, val in zip(y_indices, x_indices, vector):
             values[y, x] = val
 
         return cls(values, self)
@@ -257,8 +242,7 @@ def PDHistogram(diagram, x_ruler, y_ruler):
 
 
 class BinaryHistogram(Histogram):
-    """A PD histogram whose values are bool.
-    """
+    """A PD histogram whose values are bool."""
 
     def filter_pairs(self, pairs):
         return [pair for pair in pairs if self.value_at(pair.birth, pair.death)]
