@@ -115,3 +115,14 @@ class BitmapOptimal1Cycle(object):
         return p3d.Voxels(self.path(), color, name)
 
     to_plotly3d = to_plotly3d_trace
+
+    def to_pyvista_mesh(self):
+        """
+        Constructs a PyVista's mesh object to visualize the optimal 1-cycle
+
+        Returns:
+            pyvista.PolyData: PyVista's mesh object
+        """
+        import homcloud.pyvistahelper as pvhelper
+
+        return pvhelper.SparseVoxels(self.path())
