@@ -7,7 +7,6 @@ import json
 
 import numpy as np
 import pulp
-from forwardable import forwardable
 
 from homcloud.argparse_common import parse_range, parse_bool
 from homcloud.license import add_argument_for_license
@@ -16,6 +15,8 @@ from homcloud.pdgm import PDGM
 from homcloud.spatial_searcher import SpatialSearcher
 from homcloud.numpyencoder import NumpyEncoder
 from homcloud.visualize_3d import ParaViewSimplexDrawer, ParaViewCubeDrawer
+from homcloud.delegate import forwardable
+
 
 try:
     from pulp.solvers import PulpSolverError
@@ -64,7 +65,7 @@ def sign_function(boundary_map):
     if boundary_map["type"] == "cubical":
         return sign_cubical
 
-    raise(RuntimeError("Unknown maptype: {}".format(boundary_map["type"])))
+    raise RuntimeError("Unknown maptype: {}".format(boundary_map["type"]))
 
 
 class Optimizer(object):
@@ -90,7 +91,7 @@ class Optimizer(object):
                 partial_map[i] = list()
             elif dim(i) == degree + 1 and is_active_cell(i):
                 lpvars.append(i)
-                for (kth, j) in enumerate(map[i][1]):
+                for kth, j in enumerate(map[i][1]):
                     if j in partial_map:
                         partial_map[j].append((sign(i, kth), i))
 
@@ -98,8 +99,8 @@ class Optimizer(object):
 
     def build_lp_problem(self, lpvar_indices, partial_map):
         prob = pulp.LpProblem("OptimalVolume", pulp.LpMinimize)
-        xs = pulp.LpVariable.dicts("x", (lpvar_indices, ), -1, 1, "Continuous")
-        ys = pulp.LpVariable.dicts("y", (lpvar_indices, ), 0, 1, "Continuous")
+        xs = pulp.LpVariable.dicts("x", (lpvar_indices,), -1, 1, "Continuous")
+        ys = pulp.LpVariable.dicts("y", (lpvar_indices,), 0, 1, "Continuous")
 
         prob.setObjective(pulp.lpSum(ys.values()))
 
@@ -107,14 +108,12 @@ class Optimizer(object):
             prob.addConstraint(xs[i] - ys[i] <= 0.0)
             prob.addConstraint(xs[i] + ys[i] >= 0.0)
 
-        for (low, constraint) in partial_map.items():
+        for low, constraint in partial_map.items():
             if not constraint:
                 continue
             if low == self.birth:
                 continue
-            prob.addConstraint(
-                pulp.lpSum(s * xs[i] for (s, i) in constraint) == 0
-            )
+            prob.addConstraint(pulp.lpSum(s * xs[i] for (s, i) in constraint) == 0)
 
         prob.addConstraint(xs[self.death] == 1)
 
@@ -155,28 +154,20 @@ class Success(object):
         def valid(c):
             return c != death and c in death_to_birth
 
-        return [
-            (death_to_birth[c], c) for c in self.cell_indices if valid(c)
-        ]
+        return [(death_to_birth[c], c) for c in self.cell_indices if valid(c)]
 
     def __repr__(self):
         return "<optvol.Success: {}>".format(self.cell_indices)
 
-    def draw(self, drawer, coord_resolver, volume_color, boundary_color, index,
-             issubvolume=0):
+    def draw(self, drawer, coord_resolver, volume_color, boundary_color, index, issubvolume=0):
         coord_resolver.draw_cells(
-            drawer, self.cell_indices, volume_color,
-            index=index, issimplex=1, issubvolume=issubvolume
+            drawer, self.cell_indices, volume_color, index=index, issimplex=1, issubvolume=issubvolume
         )
         coord_resolver.draw_boundary_cells(
-            drawer, self.cell_indices, boundary_color,
-            index=index, isboundary=1, issubvolume=issubvolume
+            drawer, self.cell_indices, boundary_color, index=index, isboundary=1, issubvolume=issubvolume
         )
         if self.subvolume:
-            self.subvolume.draw(
-                drawer, coord_resolver,
-                drawer.various_colors[2], drawer.various_colors[3], index, 1
-            )
+            self.subvolume.draw(drawer, coord_resolver, drawer.various_colors[2], drawer.various_colors[3], index, 1)
 
 
 class Failure(object):
@@ -229,7 +220,7 @@ def is_active_cell(coord_resolver, center, threshold, n, cell_index):
     if threshold is None:
         return True
     centroid = np.array(coord_resolver.centroid(cell_index))
-    return np.linalg.norm(center - centroid) < threshold * (2 ** n)
+    return np.linalg.norm(center - centroid) < threshold * (2**n)
 
 
 class OptimizerBuilder(object):
@@ -242,11 +233,7 @@ class OptimizerBuilder(object):
         return Optimizer(birth, death, self.boundary_map, self.lp_solver)
 
     def to_query_dict(self):
-        return {
-            "degree": self.degree,
-            "solver-name": self.solver_name,
-            "solver-options": self.solver_options
-        }
+        return {"degree": self.degree, "solver-name": self.solver_name, "solver-options": self.solver_options}
 
     @property
     def solver_name(self):
@@ -262,15 +249,13 @@ class OptimizerBuilder(object):
     @staticmethod
     def from_alpha_pdgm(pdgm, cutoff_radius, retry, lp_solver):
         return RetryOptimizerBuilder(
-            pdgm.degree, pdgm.boundary_map_chunk, lp_solver,
-            pdgm.alpha_coord_resolver(), cutoff_radius, retry
+            pdgm.degree, pdgm.boundary_map_chunk, lp_solver, pdgm.alpha_coord_resolver, cutoff_radius, retry
         )
 
     @staticmethod
     def from_cubical_pdgm(pdgm, cutoff_radius, retry, lp_solver):
         return RetryOptimizerBuilder(
-            pdgm.degree, pdgm.boundary_map_chunk, lp_solver,
-            pdgm.cubical_geometry_resolver(), cutoff_radius, retry
+            pdgm.degree, pdgm.boundary_map_chunk, lp_solver, pdgm.cubical_geometry_resolver, cutoff_radius, retry
         )
 
     def builder_without_retry(self):
@@ -287,15 +272,18 @@ class RetryOptimizerBuilder(OptimizerBuilder):
     def build(self, birth, death):
         return RetryOptimizer(
             super().build(birth, death),
-            partial(is_active_cell, self.coord_resolver,
-                    self.coord_resolver.centroid(death), self.cutoff),
-            self.retry
+            partial(is_active_cell, self.coord_resolver, self.coord_resolver.centroid(death), self.cutoff),
+            self.retry,
         )
 
     def to_query_dict(self):
-        return dict(super().to_query_dict(), **{
-            "cutoff-radius": self.cutoff, "num-retry": self.retry,
-        })
+        return dict(
+            super().to_query_dict(),
+            **{
+                "cutoff-radius": self.cutoff,
+                "num-retry": self.retry,
+            },
+        )
 
     def builder_without_retry(self):
         return OptimizerBuilder(self.degree, self.boundary_map, self.lp_solver)
@@ -303,7 +291,7 @@ class RetryOptimizerBuilder(OptimizerBuilder):
 
 def bisect_tightened(b, d, index_to_level, epsilon):
     k = bisect(index_to_level, index_to_level[b] + epsilon, lo=b, hi=d + 1)
-    assert k <= d
+    assert k <= d, "epsilon must be smaller than lifetime"
     # 次の行で k - 1 を使っているのは，Optimizer.build_lp_problemで
     # if low == self.birth:
     #      continue
@@ -322,9 +310,7 @@ class TightenedVolumeFinder(object):
         return self.optimizer_builder.build(k, death).find()
 
     def to_query_dict(self):
-        return dict(self.optimizer_builder.to_query_dict(), **{
-            "query-target": "tightened-volume"
-        })
+        return dict(self.optimizer_builder.to_query_dict(), **{"query-target": "tightened-volume"})
 
 
 class OptimalVolumeFinder(object):
@@ -335,9 +321,7 @@ class OptimalVolumeFinder(object):
         return self.optimizer_builder.build(birth, death).find()
 
     def to_query_dict(self):
-        return dict(self.optimizer_builder.to_query_dict(), **{
-            "query-target": "optimal-volume"
-        })
+        return dict(self.optimizer_builder.to_query_dict(), **{"query-target": "optimal-volume"})
 
 
 class TightenedSubVolumeFinder(object):
@@ -349,37 +333,29 @@ class TightenedSubVolumeFinder(object):
     def find(self, birth, death, optimal_volume_cells):
         k = bisect_tightened(birth, death, self.index_to_level, self.epsilon)
         return self.optimizer_builder.build(k, death).find(
-            partial(self.is_active_cell_for_tightend_subvolume,
-                    birth, optimal_volume_cells)
+            partial(self.is_active_cell_for_tightend_subvolume, birth, optimal_volume_cells)
         )
 
-    def is_active_cell_for_tightend_subvolume(self, birth, optimal_volume_cells,
-                                              cell_index):
-        return (cell_index in optimal_volume_cells and
-                (self.index_to_level[birth] + self.epsilon <
-                 self.index_to_level[cell_index]))
+    def is_active_cell_for_tightend_subvolume(self, birth, optimal_volume_cells, cell_index):
+        return cell_index in optimal_volume_cells and (
+            self.index_to_level[birth] + self.epsilon < self.index_to_level[cell_index]
+        )
 
 
 class OptimalVolumeTightenedSubVolumeFinder(object):
     def __init__(self, optimizer_builder, index_to_level, epsilon):
         self.optimizer_builder = optimizer_builder
-        self.tsv_finder = TightenedSubVolumeFinder(
-            optimizer_builder.builder_without_retry(), index_to_level, epsilon
-        )
+        self.tsv_finder = TightenedSubVolumeFinder(optimizer_builder.builder_without_retry(), index_to_level, epsilon)
 
     def find(self, birth, death):
         optimal_volume = self.optimizer_builder.build(birth, death).find()
         if not optimal_volume.success:
             return optimal_volume
-        optimal_volume.subvolume = self.tsv_finder.find(
-            birth, death, optimal_volume.cell_indices
-        )
+        optimal_volume.subvolume = self.tsv_finder.find(birth, death, optimal_volume.cell_indices)
         return optimal_volume
 
     def to_query_dict(self):
-        return dict(self.optimizer_builder.to_query_dict(), **{
-            "query-target": "tightened-subvolume"
-        })
+        return dict(self.optimizer_builder.to_query_dict(), **{"query-target": "tightened-subvolume"})
 
 
 class PointQuery(object):
@@ -390,13 +366,16 @@ class PointQuery(object):
         self.spatial_searcher = spatial_searcher
 
     def to_dict(self):
-        return dict(self.ovfinder.to_query_dict(), **{
-            "birth": self.birth_time, "death": self.death_time,
-        })
+        return dict(
+            self.ovfinder.to_query_dict(),
+            **{
+                "birth": self.birth_time,
+                "death": self.death_time,
+            },
+        )
 
     def execute(self):
-        pair_indices, pair = self.spatial_searcher.nearest_pair(self.birth_time,
-                                                                self.death_time)
+        pair_indices, pair = self.spatial_searcher.nearest_pair(self.birth_time, self.death_time)
         result = self.ovfinder.find(*pair_indices)
         result.pair = pair
         return [result]
@@ -407,8 +386,7 @@ class PointQuery(object):
 
 
 class RectangleQuery(object):
-    def __init__(self, birth_range, death_range, ovfinder, spatial_searcher,
-                 skip_infeasible):
+    def __init__(self, birth_range, death_range, ovfinder, spatial_searcher, skip_infeasible):
         self.birth_range = birth_range
         self.death_range = death_range
         self.ovfinder = ovfinder
@@ -416,16 +394,18 @@ class RectangleQuery(object):
         self.skip_infeasible = skip_infeasible
 
     def to_dict(self):
-        return dict(self.ovfinder.to_query_dict(), **{
-            "birth-range": self.birth_range,
-            "death-range": self.death_range,
-            "skip-infeasible": self.skip_infeasible,
-        })
+        return dict(
+            self.ovfinder.to_query_dict(),
+            **{
+                "birth-range": self.birth_range,
+                "death-range": self.death_range,
+                "skip-infeasible": self.skip_infeasible,
+            },
+        )
 
     def pairs_in_rectangle(self):
         return self.spatial_searcher.in_rectangle(
-            self.birth_range[0], self.birth_range[1],
-            self.death_range[0], self.death_range[1]
+            self.birth_range[0], self.birth_range[1], self.death_range[0], self.death_range[1]
         )
 
     def execute(self):
@@ -438,7 +418,7 @@ class RectangleQuery(object):
             elif result.infeasible and self.skip_infeasible:
                 results.append(result)
             else:
-                raise(RuntimeError(result.message))
+                raise RuntimeError(result.message)
         return results
 
     @staticmethod
@@ -453,15 +433,19 @@ class SuccessToDictBase(object):
 
     def children(self, death, success):
         ret = []
-        for (b, d) in success.children(death, self.death_to_birth):
+        for b, d in success.children(death, self.death_to_birth):
             birth_time = self.index_to_level[b]
             death_time = self.index_to_level[d]
             if birth_time == death_time:
                 pass
-            ret.append({
-                "birth-time": birth_time, "death-time": death_time,
-                "birth-index": b, "death-index": d,
-            })
+            ret.append(
+                {
+                    "birth-time": birth_time,
+                    "death-time": death_time,
+                    "birth-index": b,
+                    "death-index": d,
+                }
+            )
 
         return ret
 
@@ -471,25 +455,24 @@ class SuccessToDictBase(object):
         return {
             "birth-time": self.index_to_level[birth],
             "death-time": self.index_to_level[death],
-            "birth-index": birth, "death-index": death,
+            "birth-index": birth,
+            "death-index": death,
             "success": True,
-            "tightened-subvolume": self(success.subvolume)
+            "tightened-subvolume": self(success.subvolume),
         }
 
 
 class SuccessToDictAlpha(SuccessToDictBase):
-    def __init__(self, index_to_level, coord_resolver, symbol_resolver,
-                 death_to_birth):
+    def __init__(self, index_to_level, coord_resolver, symbol_resolver, death_to_birth):
         super().__init__(index_to_level, death_to_birth)
         self.coord_resolver = coord_resolver
         self.symbol_resolver = symbol_resolver
 
     @staticmethod
     def from_pdgm(pdgm):
-        return SuccessToDictAlpha(pdgm.index_to_level,
-                                  pdgm.alpha_coord_resolver(),
-                                  pdgm.alpha_symbol_resolver(),
-                                  pdgm.death_index_to_birth_index)
+        return SuccessToDictAlpha(
+            pdgm.index_to_level, pdgm.alpha_coord_resolver, pdgm.alpha_symbol_resolver, pdgm.death_index_to_birth_index
+        )
 
     def __call__(self, success):
         if success is None:
@@ -497,29 +480,28 @@ class SuccessToDictAlpha(SuccessToDictBase):
 
         death = max(success.cell_indices)
 
-        return dict(self.basedict(success, death), **{
-            "points": self.coord_resolver.resolve_vertices(success.cell_indices),
-            "simplices": self.coord_resolver.resolve_cells(success.cell_indices),
-            "boundary": self.coord_resolver.resolve_cells(
-                self.coord_resolver.boundary_cells(success.cell_indices)
-            ),
-            "boundary-points": self.coord_resolver.resolve_vertices(
-                self.coord_resolver.boundary_cells(success.cell_indices)
-            ),
-            "points-symbols": self.symbol_resolver.resolve_vertices(
-                success.cell_indices
-            ),
-            "simplices-symbols": self.symbol_resolver.resolve_cells(
-                success.cell_indices
-            ),
-            "boundary-symbols": self.symbol_resolver.resolve_cells(
-                self.symbol_resolver.boundary_cells(success.cell_indices)
-            ),
-            "boundary-points-symbols": self.symbol_resolver.resolve_vertices(
-                self.symbol_resolver.boundary_cells(success.cell_indices)
-            ),
-            "children": self.children(death, success),
-        })
+        return dict(
+            self.basedict(success, death),
+            **{
+                "points": self.coord_resolver.resolve_vertices(success.cell_indices),
+                "simplices": self.coord_resolver.resolve_cells(success.cell_indices),
+                "boundary": self.coord_resolver.resolve_cells(
+                    self.coord_resolver.boundary_cells(success.cell_indices)
+                ),
+                "boundary-points": self.coord_resolver.resolve_vertices(
+                    self.coord_resolver.boundary_cells(success.cell_indices)
+                ),
+                "points-symbols": self.symbol_resolver.resolve_vertices(success.cell_indices),
+                "simplices-symbols": self.symbol_resolver.resolve_cells(success.cell_indices),
+                "boundary-symbols": self.symbol_resolver.resolve_cells(
+                    self.symbol_resolver.boundary_cells(success.cell_indices)
+                ),
+                "boundary-points-symbols": self.symbol_resolver.resolve_vertices(
+                    self.symbol_resolver.boundary_cells(success.cell_indices)
+                ),
+                "children": self.children(death, success),
+            },
+        )
 
 
 class SuccessToDictAbstract(SuccessToDictBase):
@@ -532,19 +514,20 @@ class SuccessToDictAbstract(SuccessToDictBase):
             return None
 
         death = max(success.cell_indices)
-        return dict(self.basedict(success, death), **{
-            "cells": self.abs_resolver.resolve_cells(success.cell_indices),
-            "boundary": self.abs_resolver.resolve_cells(
-                self.abs_resolver.boundary_cells(success.cell_indices)
-            ),
-            "children": self.children(death, success)
-        })
+        return dict(
+            self.basedict(success, death),
+            **{
+                "cells": self.abs_resolver.resolve_cells(success.cell_indices),
+                "boundary": self.abs_resolver.resolve_cells(self.abs_resolver.boundary_cells(success.cell_indices)),
+                "children": self.children(death, success),
+            },
+        )
 
     @staticmethod
     def from_pdgm(pdgm):
-        return SuccessToDictAbstract(pdgm.index_to_level,
-                                     pdgm.abstract_geometry_resolver(),
-                                     pdgm.death_index_to_birth_index)
+        return SuccessToDictAbstract(
+            pdgm.index_to_level, pdgm.abstract_geometry_resolver, pdgm.death_index_to_birth_index
+        )
 
 
 class SuccessToDictSimplicial(SuccessToDictBase):
@@ -557,27 +540,26 @@ class SuccessToDictSimplicial(SuccessToDictBase):
             return None
 
         death = max(success.cell_indices)
-        return dict(self.basedict(success, death), **{
-            "points-symbols": self.symbol_resolver.resolve_vertices(
-                success.cell_indices
-            ),
-            "simplices-symbols": self.symbol_resolver.resolve_cells(
-                success.cell_indices
-            ),
-            "boundary-symbols": self.symbol_resolver.resolve_cells(
-                self.symbol_resolver.boundary_cells(success.cell_indices)
-            ),
-            "boundary-points-symbols": self.symbol_resolver.resolve_vertices(
-                self.symbol_resolver.boundary_cells(success.cell_indices)
-            ),
-            "children": self.children(death, success)
-        })
+        return dict(
+            self.basedict(success, death),
+            **{
+                "points-symbols": self.symbol_resolver.resolve_vertices(success.cell_indices),
+                "simplices-symbols": self.symbol_resolver.resolve_cells(success.cell_indices),
+                "boundary-symbols": self.symbol_resolver.resolve_cells(
+                    self.symbol_resolver.boundary_cells(success.cell_indices)
+                ),
+                "boundary-points-symbols": self.symbol_resolver.resolve_vertices(
+                    self.symbol_resolver.boundary_cells(success.cell_indices)
+                ),
+                "children": self.children(death, success),
+            },
+        )
 
     @staticmethod
     def from_pdgm(pdgm):
-        return SuccessToDictSimplicial(pdgm.index_to_level,
-                                       pdgm.simplicial_symbol_resolver(),
-                                       pdgm.death_index_to_birth_index)
+        return SuccessToDictSimplicial(
+            pdgm.index_to_level, pdgm.simplicial_symbol_resolver, pdgm.death_index_to_birth_index
+        )
 
 
 class SuccessToDictCubical(SuccessToDictBase):
@@ -587,9 +569,9 @@ class SuccessToDictCubical(SuccessToDictBase):
 
     @staticmethod
     def from_pdgm(pdgm):
-        return SuccessToDictCubical(pdgm.index_to_level,
-                                    pdgm.cubical_geometry_resolver(),
-                                    pdgm.death_index_to_birth_index)
+        return SuccessToDictCubical(
+            pdgm.index_to_level, pdgm.cubical_geometry_resolver, pdgm.death_index_to_birth_index
+        )
 
     def __call__(self, success):
         if success is None:
@@ -597,23 +579,26 @@ class SuccessToDictCubical(SuccessToDictBase):
 
         death = max(success.cell_indices)
 
-        return dict(self.basedict(success, death), **{
-            "points": self.cube_resolver.resolve_vertices(success.cell_indices),
-            "cubes": self.cube_resolver.resolve_cells(success.cell_indices),
-            "boundary": self.cube_resolver.resolve_cells(
-                self.cube_resolver.boundary_cells(success.cell_indices)
-            ),
-            "boundary-points": self.cube_resolver.resolve_vertices(
-                self.cube_resolver.boundary_cells(success.cell_indices)
-            ),
-            "children": self.children(death, success),
-        })
+        return dict(
+            self.basedict(success, death),
+            **{
+                "points": self.cube_resolver.resolve_vertices(success.cell_indices),
+                "cubes": self.cube_resolver.resolve_cells(success.cell_indices),
+                "boundary": self.cube_resolver.resolve_cells(self.cube_resolver.boundary_cells(success.cell_indices)),
+                "boundary-points": self.cube_resolver.resolve_vertices(
+                    self.cube_resolver.boundary_cells(success.cell_indices)
+                ),
+                "children": self.children(death, success),
+            },
+        )
 
 
 def failure_to_dict(failure):
     return {
-        "birth-time": failure.pair[0], "death-time": failure.pair[1],
-        "success": False, "status": pulp.LpStatus[failure.status],
+        "birth-time": failure.pair[0],
+        "death-time": failure.pair[1],
+        "success": False,
+        "status": pulp.LpStatus[failure.status],
     }
 
 
@@ -639,37 +624,31 @@ def argument_parser():
     add_argument_for_license(p)
 
     tp = p.add_argument_group("target")
-    tp.add_argument("-d", "--degree", type=int, required=True,
-                    help="degree of PH")
+    tp.add_argument("-d", "--degree", type=int, required=True, help="degree of PH")
     tp.add_argument("-x", type=float, help="birth time of the pair")
     tp.add_argument("-y", type=float, help="death time of the pair")
-    tp.add_argument("-X", "--x-range", type=parse_range,
-                    help="birth time of the pair")
-    tp.add_argument("-Y", "--y-range", type=parse_range,
-                    help="death time of the pair")
+    tp.add_argument("-X", "--x-range", type=parse_range, help="birth time of the pair")
+    tp.add_argument("-Y", "--y-range", type=parse_range, help="death time of the pair")
 
     op = p.add_argument_group("output options")
     op.add_argument("-j", "--json-output", help="output in json format")
-    op.add_argument("-P", "--invoke-paraview", default=False,
-                    action="store_true", help="invoke paraview")
+    op.add_argument("-P", "--invoke-paraview", default=False, action="store_true", help="invoke paraview")
 
     cp = p.add_argument_group("computation parameters")
-    cp.add_argument("-T", "--type", default="optimal-volume",
-                    help="target type (*optimal-volume*, tightened-volume,"
-                    " or tightened-subvolume")
-    cp.add_argument("-e", "--epsilon", type=float, default=0.0,
-                    help="tighened-volume/subvolume epsilon")
-    cp.add_argument("-c", "--cutoff-radius", type=float,
-                    help="cut-off radius in R^n")
-    cp.add_argument("-n", "--retry", type=int, default=1,
-                    help="number of retry")
-    cp.add_argument("--skip-infeasible", default=False, type=parse_bool,
-                    help="skip infeasible (on/*off*)")
+    cp.add_argument(
+        "-T",
+        "--type",
+        default="optimal-volume",
+        help="target type (*optimal-volume*, tightened-volume," " or tightened-subvolume",
+    )
+    cp.add_argument("-e", "--epsilon", type=float, default=0.0, help="tighened-volume/subvolume epsilon")
+    cp.add_argument("-c", "--cutoff-radius", type=float, help="cut-off radius in R^n")
+    cp.add_argument("-n", "--retry", type=int, default=1, help="number of retry")
+    cp.add_argument("--skip-infeasible", default=False, type=parse_bool, help="skip infeasible (on/*off*)")
 
     sp = p.add_argument_group("solver parameters")
     sp.add_argument("--solver", help="LP solver name")
-    sp.add_argument("-O", "--option", action="append", default=[],
-                    help="options for LP solver")
+    sp.add_argument("-O", "--option", action="append", default=[], help="options for LP solver")
 
     p.add_argument("input", help="input filename")
     return p
@@ -677,18 +656,18 @@ def argument_parser():
 
 def build_spatial_searcher(diagram):
     return SpatialSearcher(
-        list(zip(zip(diagram.birth_indices, diagram.death_indices),
-                 zip(diagram.births, diagram.deaths))),
-        diagram.births, diagram.deaths
+        list(zip(zip(diagram.birth_indices, diagram.death_indices), zip(diagram.births, diagram.deaths))),
+        diagram.births,
+        diagram.deaths,
     )
 
 
-@forwardable()
+@forwardable
 class Main(object):
     def __init__(self, args):
         self.args = args
 
-    def_delegators("args", "input, degree, cutoff_radius, retry")
+    __delegator_definitions__ = {"args": ["input", "degree", "cutoff_radius", "retry"]}
 
     def run(self):
         if self.input_is_pdgm:
@@ -730,28 +709,22 @@ class Main(object):
         elif pdgm.filtration_type == "cubical":
             self.setup_cubical_pdgm(pdgm)
         else:
-            raise(RuntimeError("Unknown pdgm type: {}".format(pdgm.filtration_type)))
+            raise RuntimeError("Unknown pdgm type: {}".format(pdgm.filtration_type))
         self.filtration_type = pdgm.filtration_type
         self.spatial_searcher = build_spatial_searcher(pdgm)
         self.index_to_level = pdgm.index_to_level
 
     def setup_alpha_pdgm(self, pdgm):
-        self.optimizer_builder = OptimizerBuilder.from_alpha_pdgm(
-            pdgm, self.cutoff_radius, self.retry, self.lp_solver
-        )
+        self.optimizer_builder = OptimizerBuilder.from_alpha_pdgm(pdgm, self.cutoff_radius, self.retry, self.lp_solver)
         self.success_to_dict = SuccessToDictAlpha.from_pdgm(pdgm)
-        self.coord_resolver = pdgm.alpha_coord_resolver()
+        self.coord_resolver = pdgm.alpha_coord_resolver
 
     def setup_abstract_pdgm(self, pdgm):
-        self.optimizer_builder = OptimizerBuilder(
-            self.degree, pdgm.boundary_map_chunk, self.lp_solver
-        )
+        self.optimizer_builder = OptimizerBuilder(self.degree, pdgm.boundary_map_chunk, self.lp_solver)
         self.success_to_dict = SuccessToDictAbstract.from_pdgm(pdgm)
 
     def setup_simplicial_pdgm(self, pdgm):
-        self.optimizer_builder = OptimizerBuilder(
-            self.degree, pdgm.boundary_map_chunk, self.lp_solver
-        )
+        self.optimizer_builder = OptimizerBuilder(self.degree, pdgm.boundary_map_chunk, self.lp_solver)
         self.success_to_dict = SuccessToDictSimplicial.from_pdgm(pdgm)
 
     def setup_cubical_pdgm(self, pdgm):
@@ -759,33 +732,30 @@ class Main(object):
             pdgm, self.cutoff_radius, self.retry, self.lp_solver
         )
         self.success_to_dict = SuccessToDictCubical.from_pdgm(pdgm)
-        self.cube_resolver = pdgm.cubical_geometry_resolver()
+        self.cube_resolver = pdgm.cubical_geometry_resolver
 
     def build_ovfinder(self):
         type = self.args.type
         if type == "optimal-volume":
             return OptimalVolumeFinder(self.optimizer_builder)
         elif type == "tightened-volume":
-            return TightenedVolumeFinder(
-                self.optimizer_builder, self.index_to_level, self.args.epsilon
-            )
+            return TightenedVolumeFinder(self.optimizer_builder, self.index_to_level, self.args.epsilon)
         elif type == "tightened-subvolume":
             return OptimalVolumeTightenedSubVolumeFinder(
                 self.optimizer_builder, self.index_to_level, self.args.epsilon
             )
         else:
-            raise(RuntimeError("Unknown type: {}".format(type)))
+            raise RuntimeError("Unknown type: {}".format(type))
 
     def build_query(self, ovfinder):
         if PointQuery.valid_args(self.args):
-            return PointQuery(self.args.x, self.args.y,
-                              ovfinder, self.spatial_searcher)
+            return PointQuery(self.args.x, self.args.y, ovfinder, self.spatial_searcher)
         elif RectangleQuery.valid_args(self.args):
-            return RectangleQuery(self.args.x_range, self.args.y_range,
-                                  ovfinder, self.spatial_searcher,
-                                  self.args.skip_infeasible)
+            return RectangleQuery(
+                self.args.x_range, self.args.y_range, ovfinder, self.spatial_searcher, self.args.skip_infeasible
+            )
         else:
-            raise(RuntimeError("Invalid query"))
+            raise RuntimeError("Invalid query")
 
     def write_json(self, query, results):
         with open(self.args.json_output, "w") as f:
@@ -798,11 +768,7 @@ class Main(object):
             else:
                 return failure_to_dict(result)
 
-        return {
-            "format-version": 2.0,
-            "query": query.to_dict(),
-            "result": [result_to_dict(r) for r in results]
-        }
+        return {"format-version": 2.0, "query": query.to_dict(), "result": [result_to_dict(r) for r in results]}
 
     def invoke_paraview(self, results):
         if self.filtration_type == "alpha":
@@ -810,7 +776,7 @@ class Main(object):
         elif self.filtration_type == "cubical":
             drawer = self.draw_volumes_for_cubical(results)
         else:
-            raise(RuntimeError("Paraview visualization is not available"))
+            raise RuntimeError("Paraview visualization is not available")
 
         drawer.invoke()
 
@@ -826,21 +792,16 @@ class Main(object):
 
 
 def drawer_for_alpha(points):
-    return ParaViewSimplexDrawer(4, points, {
-        "index": None, "isboundary": 0, "issimplex": 0, "issubvolume": 0
-    })
+    return ParaViewSimplexDrawer(4, points, {"index": None, "isboundary": 0, "issimplex": 0, "issubvolume": 0})
 
 
 def drawer_for_cubical(shape):
-    return ParaViewCubeDrawer(4, shape, {
-        "index": None, "isboundary": 0, "issimplex": 0, "issubvolume": 0
-    })
+    return ParaViewCubeDrawer(4, shape, {"index": None, "isboundary": 0, "issimplex": 0, "issubvolume": 0})
 
 
 def draw_volumes(drawer, results, geom_resolver):
     for i, volume in enumerate(results):
-        volume.draw(drawer, geom_resolver,
-                    drawer.various_colors[0], drawer.various_colors[1], i)
+        volume.draw(drawer, geom_resolver, drawer.various_colors[0], drawer.various_colors[1], i)
 
 
 def main(args=None):
