@@ -1,4 +1,7 @@
 """
+*This module is now deprecated. Please use pyvista instead.*
+
+
 This module provides the paraview interface from homcloud.interface module.
 
 The basic model of this module is "pipeline" model. A data object is
@@ -23,22 +26,20 @@ from tempfile import NamedTemporaryFile
 import os
 
 import numpy as np
-from forwardable import forwardable
 
 import homcloud.utils as utils
 import homcloud.pict.pict3d_vtk as pict3d_vtk
-from homcloud.visualize_3d import (
-    ParaViewPolyLineDrawer, ParaView3DSurfaceDrawer, ParaViewLinesDrawer
-)
+from homcloud.visualize_3d import ParaViewPolyLineDrawer, ParaView3DSurfaceDrawer, ParaViewLinesDrawer
+from homcloud.delegate import forwardable
 
 
-@forwardable()
+@forwardable
 class TempFile(object):
     def __init__(self, suffix):
         self.named_tempfile = NamedTemporaryFile("w+", suffix=suffix, delete=False)
         self.cleanup_done = False
 
-    def_delegators("named_tempfile", "name, close, write")
+    __delegator_definitions__ = {"named_tempfile": ["name", "close", "write"]}
 
     def cleanup(self):
         self.close()
@@ -75,8 +76,7 @@ class PipelineNode(object):
         return "s" + str(self.index)
 
     def to_paraview_node(self):
-        """Returns self.
-        """
+        """Returns self."""
         return self
 
     def representation(self):
@@ -120,17 +120,11 @@ class PipelineNode(object):
         if self.colorbar_range is None:
             out.write(
                 "dp.LookupTable = MakeBlueToRedLT(*{}."
-                "{}[r'{}'].GetRange())\n".format(
-                    self.variable(), self.data_attr_name(), self.color_field
-                )
+                "{}[r'{}'].GetRange())\n".format(self.variable(), self.data_attr_name(), self.color_field)
             )
         else:
-            out.write("dp.LookupTable = MakeBlueToRedLT({}, {})\n".format(
-                *self.colorbar_range
-            ))
-        out.write("dp.ColorArrayName = [r'{}', r'{}']\n".format(
-            self.color_array_type(), self.color_field
-        ))
+            out.write("dp.LookupTable = MakeBlueToRedLT({}, {})\n".format(*self.colorbar_range))
+        out.write("dp.ColorArrayName = [r'{}', r'{}']\n".format(self.color_array_type(), self.color_field))
 
     def write_specialized_code(self, out, already_written):
         pass
@@ -246,9 +240,7 @@ class PipelineNode(object):
 
     def set_representation(self, rep):
         if rep not in ["Wireframe", "Points", "Surface", "Surface With Edges"]:
-            raise(ValueError(
-                "Representation {} is not acceptable".format(rep)
-            ))
+            raise ValueError("Representation {} is not acceptable".format(rep))
         self._representation = rep
         return self
 
@@ -290,10 +282,10 @@ class VTK(PipelineNode):
             self.file.cleanup()
 
     def write_constructor(self, out):
-        out.write("{} = LegacyVTKReader(FileNames=r'{}',"
-                  " guiName=r'{}')\n".format(
-                      self.variable(), self.path, self.gui_name
-                  ))
+        out.write(
+            "{} = LegacyVTKReader(FileNames=r'{}',"
+            " guiName=r'{}')\n".format(self.variable(), self.path, self.gui_name)
+        )
 
     def data_attr_name(self):
         return "CellData"
@@ -320,10 +312,10 @@ class XMLVTI(PipelineNode):
             self.file.cleanup()
 
     def write_constructor(self, out):
-        out.write("{} = XMLImageDataReader(FileName=r'{}', "
-                  "guiName=r'{}')\n".format(
-                      self.variable(), self.path, self.gui_name
-                  ))
+        out.write(
+            "{} = XMLImageDataReader(FileName=r'{}', "
+            "guiName=r'{}')\n".format(self.variable(), self.path, self.gui_name)
+        )
 
     def data_attr_name(self):
         return "CellData"
@@ -441,15 +433,17 @@ class PointCloud(PipelineNode):
 
     def write_constructor(self, out):
         def quote(s):
-            return s.translate({
-                "\t": "\\t", "\n": "\\n",
-            })
+            return s.translate(
+                {
+                    "\t": "\\t",
+                    "\n": "\\n",
+                }
+            )
 
         out.write(
             "s = CSVReader(FileName=r'{}', FieldDelimiterCharacters='{}',"
-            " guiName=r'{}', HaveHeaders=0)\n".format(
-                self.path, quote(self.delimiters), self.gui_name
-            ))
+            " guiName=r'{}', HaveHeaders=0)\n".format(self.path, quote(self.delimiters), self.gui_name)
+        )
 
         out.write(self.table_to_points_template().format(self.variable()))
 
@@ -480,16 +474,11 @@ class Threshold(PipelineNode):
         self.range = range
 
     def write_constructor(self, out):
-        out.write("{} = Threshold({})\n".format(self.variable(),
-                                                self.parent.variable()))
+        out.write("{} = Threshold({})\n".format(self.variable(), self.parent.variable()))
 
     def write_specialized_code(self, out, already_written):
-        out.write("{}.Scalars = ['CELLS', r'{}']\n".format(
-            self.variable(), self.field
-        ))
-        out.write("{}.ThresholdRange = ({}, {})\n".format(
-            self.variable(), self.range[0], self.range[1]
-        ))
+        out.write("{}.Scalars = ['CELLS', r'{}']\n".format(self.variable(), self.field))
+        out.write("{}.ThresholdRange = ({}, {})\n".format(self.variable(), self.range[0], self.range[1]))
 
 
 class SphereClip(PipelineNode):
@@ -507,17 +496,17 @@ class SphereClip(PipelineNode):
         self.inside_out = inside_out
 
     def write_constructor(self, out):
-        out.write("{} = Clip({}, InsideOut={}, ClipType='Sphere')\n".format(
-            self.variable(), self.parent.variable(), int(self.inside_out),
-        ))
+        out.write(
+            "{} = Clip({}, InsideOut={}, ClipType='Sphere')\n".format(
+                self.variable(),
+                self.parent.variable(),
+                int(self.inside_out),
+            )
+        )
 
     def write_specialized_code(self, out, already_written):
-        out.write("{}.ClipType.Center = [{}, {}, {}]\n".format(
-            self.variable(), *self.center
-        ))
-        out.write("{}.ClipType.Radius = {}\n".format(
-            self.variable(), self.radius
-        ))
+        out.write("{}.ClipType.Center = [{}, {}, {}]\n".format(self.variable(), *self.center))
+        out.write("{}.ClipType.Radius = {}\n".format(self.variable(), self.radius))
 
 
 def write_python_code(out, sources, bgcolor):
