@@ -1,6 +1,8 @@
+"""
+This module provides helper functions for plotly (https://plotly.com/python/) for HomCloud.
+"""
 import plotly.graph_objects as go
 import numpy as np
-import itertools
 
 
 def PointCloud(array, color=None, size=1, name=""):
@@ -19,12 +21,9 @@ def PointCloud(array, color=None, size=1, name=""):
     assert array.ndim == 2 and array.shape[1] >= 3
     if array.shape[1] == 4 and color is True:
         color = array[:, 3]
-    return go.Scatter3d(x=array[:, 0],
-                        y=array[:, 1],
-                        z=array[:, 2],
-                        name=name,
-                        mode='markers',
-                        marker=dict(size=size, color=color))
+    return go.Scatter3d(
+        x=array[:, 0], y=array[:, 1], z=array[:, 2], name=name, mode="markers", marker=dict(size=size, color=color)
+    )
 
 
 def SimplicesMesh(simplices, color=None, name=""):
@@ -39,19 +38,19 @@ def SimplicesMesh(simplices, color=None, name=""):
                 coordinates.append(vertex)
                 n += 1
 
-    simplices_by_vertex_index = np.array([
-        [vertices[tuple(v)] for v in simplex] for simplex in simplices
-    ])
+    simplices_by_vertex_index = np.array([[vertices[tuple(v)] for v in simplex] for simplex in simplices])
     coordinates = np.array(coordinates)
 
-    return go.Mesh3d(x=coordinates[:, 0],
-                     y=coordinates[:, 1],
-                     z=coordinates[:, 2],
-                     i=simplices_by_vertex_index[:, 0],
-                     j=simplices_by_vertex_index[:, 1],
-                     k=simplices_by_vertex_index[:, 2],
-                     name=name,
-                     color=color)
+    return go.Mesh3d(
+        x=coordinates[:, 0],
+        y=coordinates[:, 1],
+        z=coordinates[:, 2],
+        i=simplices_by_vertex_index[:, 0],
+        j=simplices_by_vertex_index[:, 1],
+        k=simplices_by_vertex_index[:, 2],
+        name=name,
+        color=color,
+    )
 
 
 def Simplices(simplices, color=None, width=1, name=""):
@@ -61,20 +60,32 @@ def Simplices(simplices, color=None, width=1, name=""):
     ys = []
     zs = []
     for simplex in simplices:
-        for (i, j) in ij_pairs:
+        for i, j in ij_pairs:
             xs.extend([simplex[i][0], simplex[j][0], None])
             ys.extend([simplex[i][1], simplex[j][1], None])
             zs.extend([simplex[i][2], simplex[j][2], None])
     return go.Scatter3d(
-        x=xs, y=ys, z=zs, mode="lines", name=name, showlegend=False, line=dict(color=color, width=width),
+        x=xs,
+        y=ys,
+        z=zs,
+        mode="lines",
+        name=name,
+        showlegend=False,
+        line=dict(color=color, width=width),
     )
 
 
 def Loop(vertices, color=None, width=1, name=""):
     vs = np.concatenate([vertices, [vertices[0]]])
-    return go.Scatter3d(x=vs[:, 0], y=vs[:, 1], z=vs[:, 2], mode="lines",
-                        line=dict(color=color, width=width), name=name,
-                        showlegend=False)
+    return go.Scatter3d(
+        x=vs[:, 0],
+        y=vs[:, 1],
+        z=vs[:, 2],
+        mode="lines",
+        line=dict(color=color, width=width),
+        name=name,
+        showlegend=False,
+    )
 
 
 class VertexIndexer(object):
@@ -128,23 +139,29 @@ class VoxelDrawer(object):
         x += self.offsets[2]
 
         if dx == 1:
-            return ((x + 0.5, y - 0.5, z - 0.5),
-                    (x + 0.5, y + 0.5, z - 0.5),
-                    (x + 0.5, y - 0.5, z + 0.5),
-                    (x + 0.5, y + 0.5, z + 0.5))
+            return (
+                (x + 0.5, y - 0.5, z - 0.5),
+                (x + 0.5, y + 0.5, z - 0.5),
+                (x + 0.5, y - 0.5, z + 0.5),
+                (x + 0.5, y + 0.5, z + 0.5),
+            )
         if dy == 1:
-            return ((x - 0.5, y + 0.5, z - 0.5),
-                    (x + 0.5, y + 0.5, z - 0.5),
-                    (x - 0.5, y + 0.5, z + 0.5),
-                    (x + 0.5, y + 0.5, z + 0.5))
+            return (
+                (x - 0.5, y + 0.5, z - 0.5),
+                (x + 0.5, y + 0.5, z - 0.5),
+                (x - 0.5, y + 0.5, z + 0.5),
+                (x + 0.5, y + 0.5, z + 0.5),
+            )
         if dz == 1:
-            return ((x - 0.5, y - 0.5, z + 0.5),
-                    (x + 0.5, y - 0.5, z + 0.5),
-                    (x - 0.5, y + 0.5, z + 0.5),
-                    (x + 0.5, y + 0.5, z + 0.5))
+            return (
+                (x - 0.5, y - 0.5, z + 0.5),
+                (x + 0.5, y - 0.5, z + 0.5),
+                (x - 0.5, y + 0.5, z + 0.5),
+                (x + 0.5, y + 0.5, z + 0.5),
+            )
 
     def graph_object(self):
-        for (dx, dy, dz) in [(1, 0, 0), (0, 1, 0), (0, 0, 1)]:
+        for dx, dy, dz in [(1, 0, 0), (0, 1, 0), (0, 0, 1)]:
             for z in range(-1, self.shape[0] + 1):
                 for y in range(-1, self.shape[1] + 1):
                     for x in range(-1, self.shape[2] + 1):
@@ -153,14 +170,16 @@ class VoxelDrawer(object):
 
         coordinates = self.vertex_indexer.coordinates()
         triangles = np.array(self.triangles)
-        return go.Mesh3d(x=coordinates[:, 0],
-                         y=coordinates[:, 1],
-                         z=coordinates[:, 2],
-                         i=triangles[:, 0],
-                         j=triangles[:, 1],
-                         k=triangles[:, 2],
-                         name=self.name,
-                         color=self.color)
+        return go.Mesh3d(
+            x=coordinates[:, 0],
+            y=coordinates[:, 1],
+            z=coordinates[:, 2],
+            i=triangles[:, 0],
+            j=triangles[:, 1],
+            k=triangles[:, 2],
+            name=self.name,
+            color=self.color,
+        )
 
 
 def Bitmap3d(bitmap, color=None, name="", offsets=[0, 0, 0]):
@@ -191,17 +210,23 @@ def Cubes1d(cubes, color, width, name):
     zs = []
     ys = []
     xs = []
-    for (cube, d) in cubes:
+    for cube, d in cubes:
         zs.extend([cube[0], cube[0] + d[0], None])
         ys.extend([cube[1], cube[1] + d[1], None])
         xs.extend([cube[2], cube[2] + d[2], None])
     return go.Scatter3d(
-        x=xs, y=ys, z=zs, mode="lines", name=name, showlegend=False, line=dict(color=color, width=width),
+        x=xs,
+        y=ys,
+        z=zs,
+        mode="lines",
+        name=name,
+        showlegend=False,
+        line=dict(color=color, width=width),
     )
 
 
-def rotate3(l, k):
-    return l[k % 3], l[(k + 1) % 3], l[(k + 2) % 3]
+def rotate3(lst, k):
+    return lst[k % 3], lst[(k + 1) % 3], lst[(k + 2) % 3]
 
 
 def ndeg2rot(ndeg):
@@ -210,7 +235,7 @@ def ndeg2rot(ndeg):
 
 def Cubes2d(cubes, color, width, name):
     xyzs = [[], [], []]
-    for (cube, d) in cubes:
+    for cube, d in cubes:
         cs1, cs2, cs3 = rotate3(xyzs, ndeg2rot(d))
         c1, c2, c3 = rotate3(cube, ndeg2rot(d))
         cs1.extend([c1, c1, c1, c1, c1, None])
@@ -218,7 +243,12 @@ def Cubes2d(cubes, color, width, name):
         cs3.extend([c3, c3, c3 + 1, c3 + 1, c3, None])
 
     return go.Scatter3d(
-        x=xyzs[0], y=xyzs[1], z=xyzs[2], mode="lines", name=name, showlegend=False,
+        x=xyzs[0],
+        y=xyzs[1],
+        z=xyzs[2],
+        mode="lines",
+        name=name,
+        showlegend=False,
         line=dict(color=color, width=width),
     )
 
@@ -230,7 +260,7 @@ def Cubes(cubes, color=None, width=1, name=""):
     elif dim == 2:
         return Cubes2d(cubes, color, width, name)
     elif dim == 3:
-        raise(RuntimeError("Dim 3 cube is not visualizable by homcloud-plotly"))
+        raise RuntimeError("Dim 3 cube is not visualizable by homcloud-plotly")
 
 
 class CubeMeshDrawer(object):
@@ -249,7 +279,7 @@ class CubeMeshDrawer(object):
     def graph_object(self):
         triangles = []
 
-        for (cube, ndeg) in self.cubes:
+        for cube, ndeg in self.cubes:
             u, v = self.UV[ndeg.index(0)]
             p0 = self.vertex_indexer.index_of(tuple(cube))
             p1 = self.vertex_indexer.index_of(tuple(u + cube))
@@ -260,9 +290,16 @@ class CubeMeshDrawer(object):
 
         coordinates = self.vertex_indexer.coordinates()
         triangles = np.array(triangles)
-        return go.Mesh3d(x=coordinates[:, 0], y=coordinates[:, 1], z=coordinates[:, 2],
-                         i=triangles[:, 0], j=triangles[:, 1], k=triangles[:, 2],
-                         name=self.name, color=self.color)
+        return go.Mesh3d(
+            x=coordinates[:, 0],
+            y=coordinates[:, 1],
+            z=coordinates[:, 2],
+            i=triangles[:, 0],
+            j=triangles[:, 1],
+            k=triangles[:, 2],
+            name=self.name,
+            color=self.color,
+        )
 
 
 def CubesMesh(cubes, color=None, name=""):
