@@ -5,13 +5,10 @@ import math
 
 import numpy as np
 
-import homcloud.utils as utils
 from homcloud.histogram import Ruler, PDHistogram
 from homcloud.version import __version__
-from homcloud.diagram import PD
-from homcloud.argparse_common import (
-    add_arguments_for_load_diagrams, add_arguments_for_histogram_rulers
-)
+import homcloud.pdgm as pdgm
+from homcloud.argparse_common import add_arguments_for_load_diagrams, add_arguments_for_histogram_rulers
 
 
 def argument_parser():
@@ -19,16 +16,13 @@ def argument_parser():
     p.add_argument("-V", "--version", action="version", version=__version__)
     add_arguments_for_load_diagrams(p)
     add_arguments_for_histogram_rulers(p)
-    p.add_argument("-D", "--gaussian-sd", type=float, required=True,
-                   help="standard deviation of gaussian diffusion")
+    p.add_argument("-D", "--gaussian-sd", type=float, required=True, help="standard deviation of gaussian diffusion")
     p.add_argument("-C", type=float, help="weight constant C")
     p.add_argument("-p", type=float, default=1.0, help="weight constant p")
     p.add_argument("-c", "--coordinates", help="file to write coordinates")
-    p.add_argument("-H", "--histogram-information",
-                   help="file to write histogram information")
+    p.add_argument("-H", "--histogram-information", help="file to write histogram information")
     p.add_argument("-o", "--output", help="output file")
-    p.add_argument("-w", "--weight-type", default="atan",
-                   help="weight type (atan(default),linear,none)")
+    p.add_argument("-w", "--weight-type", default="atan", help="weight type (atan(default),linear,none)")
     p.add_argument("--reorder-process", default=False, action="store_true")
     p.add_argument("input", help="input file")
     return p
@@ -36,7 +30,7 @@ def argument_parser():
 
 def atan_weight_function(c, p):
     def func(b, d):
-        return math.atan(c * abs(d - b)**p)
+        return math.atan(c * abs(d - b) ** p)
 
     return func
 
@@ -50,7 +44,7 @@ def linear_weight_function(death_max):
 
 def main(args=None):
     args = args or argument_parser().parse_args()
-    diagram = PD.load_diagrams(args.type, [args.input], args.degree, args.negate)
+    diagram = pdgm.load(args.input, args.type, args.degree, args.negate)
     check_args(args)
 
     histogram = tuned_histogram(diagram, args)
@@ -59,7 +53,7 @@ def main(args=None):
         np.savetxt(args.coordinates, histogram.centers_of_vectorize_bins())
 
     if args.histogram_information:
-        save_histogram_information(args.histogram_information, histogram)
+        save_histogram_information(args.histogram_information, histogram.histospec)
 
     if args.output:
         np.savetxt(args.output, histogram.vectorize())
@@ -69,7 +63,7 @@ def main(args=None):
 
 def check_args(args):
     if args.weight_type == "atan" and args.C is None:
-        raise RuntimeError("weigth \"atan\" requires option -C")
+        raise RuntimeError('weigth "atan" requires option -C')
 
 
 def tuned_histogram(diagram, args):
@@ -80,9 +74,7 @@ def tuned_histogram(diagram, args):
         if args.weight_type == "atan":
             histogram.apply_weight(atan_weight_function(args.C, args.p))
         elif args.weight_type == "linear":
-            histogram.apply_weight(
-                linear_weight_function(np.max(np.abs(diagram.lifetimes())))
-            )
+            histogram.apply_weight(linear_weight_function(np.max(np.abs(diagram.deaths - diagram.births))))
         elif args.weight_type == "none":
             pass
         else:
@@ -101,13 +93,12 @@ def tuned_histogram(diagram, args):
     return histogram
 
 
-def save_histogram_information(path, histogram):
+def save_histogram_information(path, histospec):
     with open(path, "w") as f:
-        json.dump(histogram_info_dict(histogram), f)
+        json.dump(histogram_info_dict(histospec), f)
 
 
-def histogram_info_dict(histogram):
-    histospec = histogram.histospec
+def histogram_info_dict(histospec):
     yindices, xindices = histospec.indices_for_vectorization()
     return {
         "x-edges": histospec.xedges.tolist(),
