@@ -1,39 +1,31 @@
 import argparse
-import sys
 import re
 from operator import attrgetter
 import operator
 import os
 import subprocess
 import json
-import warnings
 
 from PIL import Image, ImageFont, ImageDraw
 import numpy as np
 
-from homcloud import utils
-from homcloud.index_map import MapType
 from homcloud.version import __version__
-from homcloud.diagram import Histogram
+from homcloud.histogram import Histogram
 from homcloud.compat import TemporaryDirectory
-from homcloud.diagram import PD
+from homcloud.pdgm import PDGM
+from homcloud.argparse_common import parse_color
 
 
 def main(args=None):
-    """Main routine of this module
-    """
+    """Main routine of this module"""
     args = args or argument_parser().parse_args()
-    pd = PD.load_diagrams(args.type, [args.diagram], args.degree, args.negate)
-    if pd.filtration_type != MapType.bitmap:
-        sys.stderr.write("Incorrect index information\n")
-        exit(1)
+    pd = PDGM.open(args.diagram, args.degree)
     predicates = [predicate_from_string(string) for string in args.filter]
     if use_vectorized_histogram_mask(args):
         predicates.append(histogram_mask_predicate(args))
 
-    pairs = [pair for pair in pd.pairs_positions() if all_true(predicates, pair)]
-    output_image, marker_drawer = setup_images(open_image(args.picture),
-                                               args.scale, args.no_label)
+    pairs = [pair for pair in pairs_positions(pd) if all_true(predicates, pair)]
+    output_image, marker_drawer = setup_images(open_image(args.picture), args.scale, args.no_label)
     marker_drawer.setup_by_args(args)
 
     for pair in pairs:
@@ -46,39 +38,29 @@ def main(args=None):
 
 
 def argument_parser():
-    """Return ArgumentParser object used in this program.
-    """
+    """Return ArgumentParser object used in this program."""
     p = argparse.ArgumentParser(description="Show birth and death cubes in a 2D picture")
     p.add_argument("-V", "--version", action="version", version=__version__)
-    utils.add_arguments_for_load_diagrams(p)
-    p.add_argument("-f", "--filter", action="append", default=[],
-                   help="filters (ex: \"lifetime > 5.0\")")
-    p.add_argument("-v", "--vectorized-histogram-mask",
-                   help="0-1 vector textfile for mask")
-    p.add_argument("-H", "--histoinfo",
-                   help="vectorize histogram information (both -V and -H are required)")
-    p.add_argument("-B", "--birth", default=False, action="store_true",
-                   help="plot birth pixels")
-    p.add_argument("-D", "--death", default=False, action="store_true",
-                   help="plot death pixels")
-    p.add_argument("-L", "--line", default=False, action="store_true",
-                   help="draw line between death and birth pixels")
-    p.add_argument("-s", "--scale", default=1, type=int,
-                   help="image scaling factor (1, 3, 5, ...)")
-    p.add_argument("-M", "--marker-type", default="filled-diamond",
-                   help="marker type (point, filled-diamond(default), square, filled-square, circle, filled-circle)")
-    p.add_argument("-S", "--marker-size", default=1, type=int,
-                   help="marker size (default: 1)")
-    p.add_argument("--show-command", default="eog",
-                   help="image display command")
-    p.add_argument("--no-label", default=False, action="store_true",
-                   help="birth-death labels are not drawn")
-    p.add_argument("--birth-color", type=utils.parse_color, default=(255, 0, 0),
-                   help="birth pixel color")
-    p.add_argument("--death-color", type=utils.parse_color, default=(0, 0, 255),
-                   help="death pixel color")
-    p.add_argument("--line-color", type=utils.parse_color, default=(0, 255, 0),
-                   help="birth-death line color")
+    p.add_argument("-d", "--degree", type=int, required=True, help="degree of PH")
+    p.add_argument("-f", "--filter", action="append", default=[], help='filters (ex: "lifetime > 5.0")')
+    p.add_argument("-v", "--vectorized-histogram-mask", help="0-1 vector textfile for mask")
+    p.add_argument("-H", "--histoinfo", help="vectorize histogram information (both -V and -H are required)")
+    p.add_argument("-B", "--birth", default=False, action="store_true", help="plot birth pixels")
+    p.add_argument("-D", "--death", default=False, action="store_true", help="plot death pixels")
+    p.add_argument("-L", "--line", default=False, action="store_true", help="draw line between death and birth pixels")
+    p.add_argument("-s", "--scale", default=1, type=int, help="image scaling factor (1, 3, 5, ...)")
+    p.add_argument(
+        "-M",
+        "--marker-type",
+        default="filled-diamond",
+        help="marker type (point, filled-diamond(default), square, filled-square, circle, filled-circle)",
+    )
+    p.add_argument("-S", "--marker-size", default=1, type=int, help="marker size (default: 1)")
+    p.add_argument("--show-command", default="eog", help="image display command")
+    p.add_argument("--no-label", default=False, action="store_true", help="birth-death labels are not drawn")
+    p.add_argument("--birth-color", type=parse_color, default=(255, 0, 0), help="birth pixel color")
+    p.add_argument("--death-color", type=parse_color, default=(0, 0, 255), help="death pixel color")
+    p.add_argument("--line-color", type=parse_color, default=(0, 255, 0), help="birth-death line color")
     p.add_argument("-o", "--output", help="output filername")
     p.add_argument("picture", help="input Picture file name")
     p.add_argument("diagram", help="persistence diagram file name")
@@ -86,10 +68,7 @@ def argument_parser():
 
 
 RE_PREDICATE_PAIR = re.compile(r"(lifetime|birth|death)\s*(>|<|>=|<=|==)\s*(-?\d+\.?\d*)")
-OPERATORS = {
-    ">": operator.gt, "<": operator.lt, ">=": operator.ge,
-    "<=": operator.le, "==": operator.eq
-}
+OPERATORS = {">": operator.gt, "<": operator.lt, ">=": operator.ge, "<=": operator.le, "==": operator.eq}
 
 
 def predicate_from_string(string):
@@ -153,14 +132,12 @@ def display_picture(command, image):
 
 
 def all_true(predicates, obj):
-    """Return True for all predicates returns True
-    """
+    """Return True for all predicates returns True"""
     return all(predicate(obj) for predicate in predicates)
 
 
 def open_image(path):
-    """Open image file and convert it to accept colored drawings
-    """
+    """Open image file and convert it to accept colored drawings"""
     return Image.open(path).convert("RGB")
 
 
@@ -177,8 +154,7 @@ def setup_images(picture, scale, no_label):
 
 
 def pairs_positions(pd):
-    warnings.warn("view_index_pict.pairs_positions is obsolete. Please use PD.pairs_positions")
-    return pd.pairs_positions()
+    return (Pair(*args) for args in zip(pd.births, pd.deaths, pd.birth_positions, pd.death_positions))
 
 
 class Pair(object):
@@ -194,9 +170,7 @@ class Pair(object):
 
     def display_str(self):
         return "({0}, {1}) - ({2}, {3}) ({4}, {5})".format(
-            self.birth, self.death,
-            self.birth_pos[0], self.birth_pos[1],
-            self.death_pos[0], self.death_pos[1]
+            self.birth, self.death, self.birth_pos[0], self.birth_pos[1], self.death_pos[0], self.death_pos[1]
         )
 
     def __repr__(self):
@@ -240,8 +214,7 @@ class MarkerDrawer(object):
     def put_label(self, pos, pair, color):
         if self.no_label:
             return
-        self.draw.text(scaling(pos, self.scale), "({}, {})".format(pair.birth, pair.death),
-                       font=self.font, fill=color)
+        self.draw.text(scaling(pos, self.scale), "({}, {})".format(pair.birth, pair.death), font=self.font, fill=color)
 
     def put_birth_marker(self, pair):
         self.put_marker(pair.birth_pos, self.birth_color)
@@ -269,9 +242,9 @@ class MarkerDrawer(object):
         Args:
         pair -- Pair object
         """
-        self.draw.line([scaling(pair.birth_pos, self.scale),
-                        scaling(pair.death_pos, self.scale)],
-                       fill=self.line_color, width=1)
+        self.draw.line(
+            [scaling(pair.birth_pos, self.scale), scaling(pair.death_pos, self.scale)], fill=self.line_color, width=1
+        )
         self.put_marker(pair.birth_pos, self.birth_color)
         self.put_marker(pair.death_pos, self.death_color)
 
@@ -279,18 +252,17 @@ class MarkerDrawer(object):
         x, y = scaling(pos, self.scale)
 
         def bounding_box():
-            return [x - self.marker_size, y - self.marker_size,
-                    x + self.marker_size, y + self.marker_size]
+            return [x - self.marker_size, y - self.marker_size, x + self.marker_size, y + self.marker_size]
 
         def put_point():
             self.draw.point((x, y), fill=color)
 
         def put_filled_diamond():
-            for dx in range(-self.marker_size, self.marker_size+1):
-                for dy in range(-self.marker_size, self.marker_size+1):
+            for dx in range(-self.marker_size, self.marker_size + 1):
+                for dy in range(-self.marker_size, self.marker_size + 1):
                     if abs(dx) + abs(dy) > self.marker_size:
                         continue
-                    self.draw.point((x+dx, y+dy), fill=color)
+                    self.draw.point((x + dx, y + dy), fill=color)
 
         def put_circle():
             self.draw.ellipse(bounding_box(), outline=color)
